@@ -1,6 +1,7 @@
 from pypop7.optimizers.cem.cem import CEM
 from pypop7.optimizers.cem.scem import SCEM
+from pypop7.optimizers.cem.dscem import DSCEM
 
 
 __all__ = [CEM,  # base (abstract) class
-           SCEM]
+           SCEM, DSCEM]
